#!/usr/bin/env python

"""
Input context common functionality.

Copyright (C) 2018 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import codecs

class Input:

    "A common input context abstraction."

    default_encoding = "utf-8"

    def __init__(self, parameters=None):

        "Initialise the input context with the optional 'parameters'."

        self.parameters = parameters
        self.encoding = parameters and parameters.get("encoding") or self.default_encoding

    def readfile(self, filename, encoding=None):

        """
        Return the contents of the file having the given 'filename'. If the
        optional 'encoding' is specified, override the general encoding.
        """

        f = codecs.open(filename, encoding=encoding or self.encoding)
        try:
            return f.read()
        finally:
            f.close()

# vim: tabstop=4 expandtab shiftwidth=4
