#!/usr/bin/env python

"""
Moin wiki serialisers.

Copyright (C) 2017, 2018 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from moinformat.links import make_linker
from moinformat.output import make_output
from moinformat.serialisers.manifest import serialisers
from moinformat.serialisers.moin.moin import MoinSerialiser
from os.path import curdir

# Top-level functions.

def get_serialiser(name):

    "Return the main serialiser class for the format having the given 'name'."

    return serialisers["%s.moin" % name]

def make_serialiser(name, output=None, linker=None):

    """
    Return a serialiser instance for the format having the given 'name'.

    The optional 'output' context is used to control where separate resources
    are stored, with the default being no storage of such resources.

    The optional 'linker' is used to control which linking scheme is used with
    the serialiser, with the default having the same name as the serialiser.
    """

    output = output or make_output("standalone")
    linker = linker or make_linker(name, "")
    return get_serialiser(name)(output, serialisers, linker)

def serialise(doc, serialiser=None):

    """
    Serialise 'doc' using the given 'serialiser' instance or the Moin serialiser
    if omitted.
    """

    if not serialiser:
        output = make_output("standalone")
        serialiser = MoinSerialiser(output, serialisers)

    doc.to_string(serialiser)
    return serialiser.get_output()

# vim: tabstop=4 expandtab shiftwidth=4
